function [w,K] = map_Finv_u(w1,K1,u,mu) ;

% 2D "periapsis kick" (inverse) map
%
% From an approximation of the restricted three-body problem which approximates
% the effect of perturbations by the smaller mass on orbital elements (where
% the orbital elements approximate a Kepler ellipse about the larger mass)
% 
% The map is from Picard's method over one ellipse from apoapsis to apoapsis
%
% Map F takes the angle of peripase (w1) and Keplerian energy (K1),
% and a small control (u), representing the "Delta-V" at periapse, which can
% be positive or negative, 
% and yields the values (w,K) after one iterate of the inverse map F^{-1}
%
% The mass parameter mu, Jacobi constant CJ, and abar are parameters of the map.  
%
% Yields trajectories,
%
% ((w_0,K_0),(w_1,K_1),...,(w_n,K_n))
%
% mu is the measure of the perturbation (mu=0 for no perturbation)
% mu=0 case leads to "invariant circles", lines of constant K
%
% Shane Ross
% shaneross.com
% September 2006

warning off MATLAB:fzero:UndeterminedSyntax

global II alpha

w = w1 + 2*pi*(-2*K1)^(-3/2) ;

% f is the energy kick function
f = -Rintegral(w) +sin(w)*II  ; 

K = K1 - mu*f - alpha*u;		
